==> nextcloud-app-calendar-1%3A1.7.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/uk.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Календар",
    "%s has published the calendar »%s«" : "%s опублікував календар »%s«",
    "Hello," : "Привіт,",
    "Too many redirects. Aborting ..." : "Забагато перенаправлень. Скасовую...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Віддалений сервер не дає нам доступ до календаря (HTTP {%s} помилок)",
    "Error connecting to remote server" : "Помилка з'єднання з віддаленим сервером",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Помилка при запиті ресурсу на віддаленому сервері. Це може можливо бути пов'язано з невідповідністю сертифіката",
    "Error requesting resource on remote server" : "Помилка при запиті ресурсів на віддаленому сервері",
    "Individual" : "індивідуальний",
    "Group" : "Група",
    "Resource" : "Ресурс",
    "Room" : "Кімната",
    "Unknown" : "Невідомо",
    "Required" : "Вимагається",
    "Optional" : "Опціонально",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ви перебуваєте в невідомому часовому поясі ({tz}), відкотитися до UTC",
    "Please create a calendar first." : "Будь ласка, створіть календар в першу чергу.",
    "New event" : "Нова подія",
    "CalDAV address for clients" : "CalDAV адреса для клієнтів",
    "Share Calendar" : "Розподілити Календар",
    "Shared" : "Опубліковано",
    "WebDAV address for subscriptions" : "WebDAV адреса для підписки",
    "Email sent." : "Email надіслано.",
    "Could not send your email." : "Неможливо надіслати мейл",
    "group" : "група",
    "Details" : "Деталі",
    "Attendees" : "Учасників",
    "Reminders" : "Нагадування",
    "Repeating" : "Повторення",
    "Confirmed" : "Підтверджено",
    "Tentative" : "Попередній",
    "Cancelled" : "Відмінено",
    "Please add a title." : "Будь ласка, додайте назву.",
    "Please select a calendar." : "Будь ласка, виберіть календар.",
    "Global" : "Загальний",
    "None" : "Жоден",
    "Every day" : "Щоденно",
    "Every week" : "Щотижня",
    "Every month" : "Щомісяця",
    "Every year" : "Щорічно",
    "never" : "ніколи",
    "after" : "після",
    "How about getting started by importing some calendars?" : "Як щодо початку роботи за рахунок імпорту деяких календарів?",
    "At time of event" : "Час події",
    "5 minutes before" : "за 5 хвилин",
    "10 minutes before" : "за 10 хвилин",
    "15 minutes before" : "за 15 хвилин",
    "30 minutes before" : "за 30 хвилин",
    "1 hour before" : "за 1 годину",
    "2 hours before" : "за 2 години",
    "Audio" : "Аудіо",
    "Email" : "Email",
    "Pop-up" : "Виринаюче вікно",
    "sec" : "сек",
    "min" : "хв",
    "hours" : "годин",
    "days" : "днів",
    "week" : "тиждень",
    "before" : "за",
    "start" : "початок",
    "end" : "кінець",
    "Editing reminders of unknown type not supported." : "Редагування нагадування невідомого типу не підтримується.",
    "Week {number} of {year}" : "Тиждень {number} з {year}",
    "Successfully imported {imported} objects" : "Вдало імпортовано {imported} об’єкти",
    "Audio alarm {time} before the event starts" : "Аудіо сигнал {time} перед початком події",
    "Pop-up {time} before the event starts" : "Повідомлення {time} перед початком події",
    "Email {time} before the event starts" : "Надіслати Email {time} перед початком події",
    "None {time} before the event starts" : "Нічого {time} перед початком поді",
    "{type} {time} before the event starts" : "{type} {time} перед початком події",
    "Audio alarm {time} before the event ends" : "Аудіо сигнал {time} напередодні закінчення події",
    "Pop-up {time} before the event ends" : "Повідомлення {time} напередодні закінчення події",
    "Title of the Event" : "Назва події",
    "Delete" : "Видалити",
    "Cancel" : "Скасувати",
    "More ..." : "Більше ...",
    "Create" : "Створити",
    "Update" : "Оновити",
    "Close" : "Закрити",
    "Location" : "Місце",
    "Description" : "Опис",
    "Export" : "Експорт",
    "Day" : "День",
    "Week" : "Тиждень",
    "Month" : "Місяць",
    "Today" : "Сьогодні",
    "More" : "Більше",
    "Edit" : "Редагувати",
    "Link" : "Посилання",
    "Download" : "Завантажити",
    "can edit" : "може редагувати",
    "Share link" : "Поширити посилання",
    "Public access" : "Публічний доступ",
    "New Calendar" : "Новий Календар",
    "Name" : "Ім’я",
    "New Subscription" : "Нова підписка",
    "Calendar does not exist" : "Календар не існує",
    "Edit event" : "Редагувати подію",
    "Delete Event" : "Видалити подію",
    "Save Event" : "Зберегти подію",
    "Time" : "Час",
    "Type" : "Тип",
    "Repeat" : "Повторювати",
    "Add" : "Додати",
    "from" : "З",
    "to" : "в",
    "Repeat every ..." : "Повторювати кожні ...",
    "Import Calendars" : "Імпортувати календарі",
    "Import canceled" : "Імпорт скасовано",
    "Analyzing calendar" : "Аналізую календар",
    "New calendar" : "Новий календар",
    "Import calendar" : "Імпортувати календар",
    "No Calendars selected for import" : "Не обрані календарі для імпорту",
    "Show week numbers" : "Показувати номери тижнів",
    "Timezone" : "Часовий пояс",
    "Primary CalDAV address" : "Первинна CalDAV адреса",
    "Subscribe" : "Підписатися"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-app-calendar-1%3A2.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/uk.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Календар",
    "%s has published the calendar »%s«" : "%s опублікував календар »%s«",
    "Hello," : "Привіт,",
    "Cheers!" : "Будьмо!",
    "Today" : "Сьогодні",
    "Day" : "День",
    "Week" : "Тиждень",
    "Month" : "Місяць",
    "Download" : "Завантажити",
    "Delete" : "Видалити",
    "Share link" : "Поширити посилання",
    "Delete share link" : "Видалити посилання для спільного використання",
    "Share with users or groups" : "Поділитися з користувачем або групою",
    "can edit" : "може редагувати",
    "New calendar" : "Новий календар",
    "Filename" : "Ім'я файлу",
    "Cancel" : "Скасувати",
    "Automatic" : "Автоматично",
    "Show week numbers" : "Показувати номери тижнів",
    "Email" : "Email",
    "Unknown" : "Невідомо",
    "All day" : "Всі дні",
    "from" : "З",
    "to" : "в",
    "never" : "ніколи",
    "after" : "після",
    "Repeat" : "Повторювати",
    "Monday" : "Понеділок",
    "More" : "Більше",
    "Save" : "Зберегти",
    "Update" : "Оновити",
    "Personal" : "Особисте",
    "Details" : "Деталі",
    "Attendees" : "Учасників",
    "Reminders" : "Нагадування",
    "Activity" : "Активність",
    "Close" : "Закрити",
    "Anniversary" : "Річниця",
    "Week {number} of {year}" : "Тиждень {number} з {year}",
    "Daily" : "Щоденно",
    "Weekly" : "Щотижня",
    "Location" : "Місце",
    "Description" : "Опис",
    "Confirmed" : "Підтверджено",
    "Tentative" : "Попередній",
    "Cancelled" : "Відмінено",
    "Presentation" : "Презентація",
    "Office" : "Офіс",
    "Mail" : "Повідомлення",
    "Play" : "Грати",
    "Global" : "Загальний"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
